//
//  GOClient.m
//  Game On!
//
//  Created by JFClifton on 10/12/13.
//  Copyright (c) 2013 Jordan Clifton. All rights reserved.
//

#import "GOClient.h"

@implementation GOClient

#pragma mark - Singleton

+(instancetype)client
{
    static GOClient * requests = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        requests = [[GOClient alloc] initWithBaseURL:[NSURL URLWithString:kBaseURL]];
    });
    return requests;
}

#pragma mark - custom initialization

-(id)initWithBaseURL:(NSURL *)url
{
    self = [super initWithBaseURL:url];
    if (self)
    {
        self.requestSerializer = [AFJSONRequestSerializer new];
        self.responseSerializer = [AFJSONResponseSerializer new];
        [self.requestSerializer setValue:kParseAppID forHTTPHeaderField:@"X-Parse-Application-Id"];
        [self.requestSerializer setValue:kParseRESTID forHTTPHeaderField:@"X-Parse-REST-API-Key"];

//        [self setDefaultHeader:@"X-Parse-Application-Id" value:kParseAppID];
//        [self setDefaultHeader:@"X-Parse-REST-API-Key" value:kParseRESTID];
//        [self setDefaultHeader:@"Accept" value:@"application/json"];
//        [self setDefaultHeader:@"content-type" value:@"application/json"];
    }
    return self;
}

#pragma mark - Custom fetching functions

-(void)fetchSymbols:(NSArray *)symbols completion:(FetchedSymbols)fetchedSymbolsBlock
{
    [self GET:@"class/games" parameters:@{@"symbols": symbols} success:^(NSURLSessionDataTask *task, id responseObject) {
        fetchedSymbolsBlock(responseObject);
    } failure:^(NSURLSessionDataTask *task, NSError *error) {
        fetchedSymbolsBlock([NSArray new]);
        NSLog(@"ERROR: %@", error);
    }];
}

-(void)getGames
{
    [self GET:@"classes/games" parameters:nil success:^(NSURLSessionDataTask *task, id responseObject) {
        if([self.delegate respondsToSelector:@selector(GOClient:didGetGames:)])
            [self.delegate GOClient:self didGetGames:responseObject];
    } failure:^(NSURLSessionDataTask *task, NSError *error) {
        if([self.delegate respondsToSelector:@selector(GOClient:didFailWithError:)])
            [self.delegate GOClient:self didFailWithError:error];
    }];
}


//-(void)getGames
//{
//    [self getPath:@"classes/games"
//       parameters:nil
//          success:^(AFHTTPRequestOperation *operation, id responseObject) {
//              if([self.delegate respondsToSelector:@selector(GOParseAPIClient:didGetGames:)])
//                  [self.delegate GOParseAPIClient:self didGetGames:responseObject];
//          }
//          failure:^(AFHTTPRequestOperation *operation, NSError *error) {
//              if([self.delegate respondsToSelector:@selector(GOParseAPIClient:didFailWithError:)])
//                  [self.delegate GOParseAPIClient:self didFailWithError:error];
//          }];
//}

@end
