//
//  GOSecondViewController.m
//  Game On!
//
//  Created by Jordan Clifton on 7/22/13.
//  Copyright (c) 2013 Jordan Clifton. All rights reserved.
//

#import "GOCreateViewController.h"
#import <Parse/Parse.h>

@interface GOCreateViewController ()

@property (nonatomic, strong) NSMutableArray *gameNameArray;
@property (nonatomic, strong) NSArray *skillLevelArray;

@end

@implementation GOCreateViewController

BOOL gameSelection;
BOOL skillSelection;
BOOL isPrivate;

BOOL gameExist;
BOOL skillExist;
BOOL titleExist;

NSInteger selectedRow;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        self.title = @"Create Group";
        self.tabBarItem.image = [UIImage imageNamed:@"second"];
    }
    return self;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
}
							
- (void)viewDidLoad
{
    [super viewDidLoad];
    
    [self.scrollView setContentSize:CGSizeMake(320, 560)];
    
    self.scrollView.backgroundColor = [UIColor colorWithPatternImage:[UIImage imageNamed:@"background.png"]];
    
    // Set placeholder text color
    self.gameTF.placeholder = @"Select a game";
//    self.gameTF.placeholderTextColor = [UIColor blackColor];
    self.skillTF.placeholder = @"Select a skill level";
//    self.skillTF.placeholderTextColor = [UIColor blackColor];
    self.titleTF.placeholder = @"Title of group";
//    self.titleTF.placeholderTextColor = [UIColor blackColor];
    self.descriptionTF.placeholder = @"Enter a group description";
    
    // Populate game name array for picker
    self.gameNameArray = [[NSMutableArray alloc] initWithCapacity:1];
    self.gameNameArray = [[NSUserDefaults standardUserDefaults] objectForKey:@"gameNameArray"];
    
    // Set initial privacy
    isPrivate = NO;
    
    // Populate skill level array
    self.skillLevelArray = @[@"Beginner", @"Intermediate", @"Expert"];
    
    [self setupPicker];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Button Actions

- (void)pickerDoneClicked {
    
    if (gameSelection) {
        self.gameTF.text = [self.gameNameArray objectAtIndex:selectedRow];
        [self.gameTF resignFirstResponder];
        selectedRow = 0;
    } else {
        
        switch (selectedRow) {
            case 0:
                self.skillTF.textColor = [UIColor greenColor];
                break;
            case 1:
                self.skillTF.textColor = [UIColor blueColor];
                break;
            case 2:
                self.skillTF.textColor = [UIColor redColor];
                break;
            default:
                break;
        }
        
        self.skillTF.text = [self.skillLevelArray objectAtIndex:selectedRow];
        [self.skillTF resignFirstResponder];
        selectedRow = 0;
    }
    
}

- (IBAction)onCreate:(id)sender {
    
    // First check fields
    [self checkFields];
    PFUser *currentUser = [PFUser currentUser];
    
    if (!currentUser) {
        [[[UIAlertView alloc] initWithTitle:@"Error"
                                    message:@"You must Log in/Register before you can create a group"
                                   delegate:nil
                          cancelButtonTitle:@"OK"
                          otherButtonTitles: nil]
         show];
    }
    
    else if (gameExist && skillExist && ![self.titleTF.text isEqualToString:@""]) {
//        NSLog(@"good data");
//        GOParseAPIClient *client = [GOParseAPIClient sharedClient];
//        client.delegate = self;
//        [client createGroupWithGame:self.gameTF.text GroupTitle:self.titleTF.text SkillLevel:self.skillTF.text MaxPartySize:ceilf(self.playerSlider.value) GroupDetails:self.descriptionTF.text Privacy:isPrivate gPassword:self.passwordTF.text Creator:currentUser.username];
    }
}

- (IBAction)dismissKeyboard:(id)sender {
    [self resignFirstResponder];
}

- (IBAction)onSliderMove:(id)sender {
//    float numFromSlider = self.playerSlider.value;
//    NSLog(@"numFromslider: %f", numFromSlider);
//    self.numOfPlayers.text = [NSString stringWithFormat:@"You + %.0f others", self.playerSlider.value-1];
}

- (IBAction)privacyChanged:(id)sender {
    if (self.segControl.selectedSegmentIndex == 0) {
        // Open
        isPrivate = NO;
        self.passwordTF.text = @"";
        [UIView animateWithDuration:0.5 animations:^{
            self.passwordTF.alpha = 0;
        }];
    } else {
        // Private
        isPrivate = YES;
        NSLog(@"private");
        [UIView animateWithDuration:0.5 animations:^{
            self.passwordTF.alpha = 1;
        }];
    }
}

- (IBAction)sliderChanged:(id)sender {
    int sliderValue;
    sliderValue = lroundf(self.playerSlider.value);
    [self.playerSlider setValue:sliderValue animated:YES];
    self.numOfPlayers.text = [NSString stringWithFormat:@"You + %.0f others", self.playerSlider.value-1];
}

#pragma mark - Picker Delegates

- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView
{
    return 1;
}
- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component
{
    if (gameSelection) {
        return self.gameNameArray.count;
    } else {
        return self.skillLevelArray.count;
    }
    
}
- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component
{
    if (gameSelection) {
        return [self.gameNameArray objectAtIndex:row];
    } else {
        return [self.skillLevelArray objectAtIndex:row];
    }
    
}

- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component
{
    selectedRow = row;
}

#pragma mark - TextField Delegates

- (void)textFieldDidBeginEditing:(UITextField *)textField
{
    if ([textField isEqual:self.gameTF]) {
        gameSelection = YES;
        skillSelection = NO;
        
        // Displays game title picker
        [self.picker reloadAllComponents];
        [self.picker selectRow:0 inComponent:0 animated:NO];
    }
    
    if ([textField isEqual:self.skillTF]) { // Skill level
        skillSelection = YES;
        gameSelection = NO;
        
        // Displays skill level picker
        [self.picker reloadAllComponents];
        [self.picker selectRow:0 inComponent:0 animated:NO];
    }
    
    if ([textField isEqual:self.passwordTF]) {
        [self.scrollView setContentOffset:CGPointMake(0, 300) animated:YES];
    }
}

#pragma mark - Picker Setup

- (void)setupPicker
{
    // create a UIPicker view as a custom keyboard view
    UIPickerView* pickerView = [[UIPickerView alloc] init];
    [pickerView sizeToFit];
    pickerView.autoresizingMask = (UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight);
    pickerView.delegate = self;
    pickerView.dataSource = self;
    pickerView.showsSelectionIndicator = YES;
    self.picker = pickerView;  //UIPickerView
    
    self.gameTF.inputView = pickerView;
    self.skillTF.inputView = pickerView;
    
    // create a done view + done button, attach to it a doneClicked action, and place it in a toolbar as an accessory input view...
    // Prepare done button
    UIToolbar* keyboardDoneButtonView = [[UIToolbar alloc] init];
    keyboardDoneButtonView.barStyle = UIBarStyleBlack;
    keyboardDoneButtonView.translucent = YES;
    keyboardDoneButtonView.tintColor = nil;
    [keyboardDoneButtonView sizeToFit];
    
    UIBarButtonItem* doneButton = [[UIBarButtonItem alloc] initWithTitle:@"Done"
                                                                   style:UIBarButtonItemStyleBordered target:self
                                                                  action:@selector(pickerDoneClicked)];
    
    [keyboardDoneButtonView setItems:[NSArray arrayWithObjects:doneButton, nil]];
    
    // Plug the keyboardDoneButtonView into the text field...
    self.gameTF.inputAccessoryView = keyboardDoneButtonView;
    self.skillTF.inputAccessoryView = keyboardDoneButtonView;
}

#pragma mark - Validation Checks

-(void)checkFields {
    
    // Check if game name text field is an actual game
    for (int i=0; i<self.gameNameArray.count; i++) {
        if ([self.gameTF.text isEqualToString:[self.gameNameArray objectAtIndex:i]])
        {
            gameExist = YES;
            break;
        } else {
            gameExist = NO;
        }
    }
    
    for (int i=0; i<self.skillLevelArray.count; i++) {
        if ([self.skillTF.text isEqualToString:[self.skillLevelArray objectAtIndex:i]])
        {
            skillExist = YES;
            break;
        } else {
            skillExist = NO;
        }
    }
    
    if (![self.titleTF.text isEqualToString:@""]) {
        titleExist = YES;
    } else {
        titleExist = NO;
    }
    
    if (!titleExist || !gameExist || !skillExist) {
        [[[UIAlertView alloc] initWithTitle:@"Field Error"
                                    message:@"Entries for Title, Game, and Skill must be valid"
                                   delegate:nil
                          cancelButtonTitle:@"OK"
                          otherButtonTitles: nil]
         show];

    }
    
}

#pragma mark - Parse client delegates

//-(void)GOParseAPIClient:(GOParseAPIClient *)client didCreateGroup:(id)response
//{
//    NSLog(@"created group response: %@", response);
//    
//}
//
//-(void)GOParseAPIClient:(GOParseAPIClient *)client didFailWithError:(NSError *)error; {
//    UIAlertView *av = [[UIAlertView alloc] initWithTitle:@"Error" message:error.localizedDescription delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
//    [av show];
//}

@end
