//
//  GOFirstViewController.m
//  Game On!
//
//  Created by Jordan Clifton on 7/22/13.
//  Copyright (c) 2013 Jordan Clifton. All rights reserved.
//

#import "GOGameListViewController.h"
#import "Game.h"
#import "GOGroupsViewController.h"
#import "GOGameCell.h"
#import <Parse/Parse.h>

@interface GOGameListViewController ()

@property (nonatomic, strong) NSMutableArray *gameListArray;
@property (nonatomic, strong) NSMutableArray *gameNameArray;

@end

@implementation GOGameListViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        self.title = @"Game List";
        self.tabBarItem.image = [UIImage imageNamed:@"first"];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    self.view.backgroundColor = [UIColor colorWithPatternImage:[UIImage imageNamed:@"background.png"]];
    
    self.gameListArray = [[NSMutableArray alloc] initWithCapacity:1];
    self.gameNameArray = [[NSMutableArray alloc] initWithCapacity:1];
    
    GOClient *client = [GOClient client];
    client.delegate = self;
    [client getGames];
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - UITableView Delegates

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
    return [self.gameListArray count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    
    static NSString *MyIdentifier = @"MyIdentifier";
    
    GOGameCell *cell = (GOGameCell *)[tableView dequeueReusableCellWithIdentifier:MyIdentifier];
    if (cell == nil)
    {
        NSArray *nib = [[NSBundle mainBundle] loadNibNamed:@"GOGameCell" owner:self options:nil];
        cell = [nib objectAtIndex:0];
    }
    
    Game *game = [self.gameListArray objectAtIndex:indexPath.row];
    
    cell.gameLabel.text = game.title;
    cell.partyNumLabel.text = [NSString stringWithFormat:@"%@", game.numOfGroups];
    
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Show groups of selected game
    GOGroupsViewController *groupsvc = [[GOGroupsViewController alloc] initWithNibName:@"GOGroupsViewController" bundle:nil];
    Game *game = [[Game alloc] init];
    game = [self.gameListArray objectAtIndex:indexPath.row];
    groupsvc.game = game;
    groupsvc.title = game.title;
    
    [self.navigationController pushViewController:groupsvc animated:YES];
    
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}

#pragma mark - Parse Delegate Methods

-(void)GOClient:(GOClient *)client didGetGames:(id)response
{
    NSArray *results = [response objectForKey:@"results"];
    for (NSDictionary *dict in results) {
        Game *game = [[Game alloc] init];
        [game gameWithDictionary:dict];
        [self.gameListArray addObject:game];
    }
    
}

-(void)GOClient:(GOClient *)client didFailWithError:(NSError *)error
{
    UIAlertView *av = [[UIAlertView alloc] initWithTitle:@"Error" message:error.localizedDescription delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
    [av show];
}

//-(void)GOParseAPIClient:(GOParseAPIClient *)client didGetGames:(id)response {
//    NSArray *results = [response objectForKey:@"results"];
//    
//    for (NSDictionary *dict in results) {
//        Game *game = [[Game alloc] init];
//        [game gameWithDictionary:dict];
//        [self.gameListArray addObject:game];
//        [self.gameNameArray addObject:game.title];
//    }
//    
//    for (int i=0; i<self.gameListArray.count; i++) {
//        Game *g = [self.gameListArray objectAtIndex:i];
//        PFQuery *query = [PFQuery queryWithClassName:@"Groups"];
//        [query whereKey:@"whichGame" equalTo:g.title];
//        
//        g.numOfGroups = [NSNumber numberWithInteger:[query countObjects]];
//
//        if (i == self.gameListArray.count-1){
//            [self.gameListTable reloadData];
//        }
//    }
//    
//    // Set a NSUserDefault to use for picker on second tab
//    [[NSUserDefaults standardUserDefaults] setObject:self.gameNameArray forKey:@"gameNameArray"];
//    
//}
//
//-(void)GOParseAPIClient:(GOParseAPIClient *)client didFailWithError:(NSError *)error; {
//    UIAlertView *av = [[UIAlertView alloc] initWithTitle:@"Error" message:error.localizedDescription delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
//    [av show];
//}

@end
