//
//  GOGroupsViewController.m
//  Game On!
//
//  Created by Jordan Clifton on 7/24/13.
//  Copyright (c) 2013 Jordan Clifton. All rights reserved.
//

#import "GOGroupsViewController.h"
#import "GOGroupCell.h"
#import <Parse/Parse.h>
#import "GOGroupDetailsViewController.h"

@interface GOGroupsViewController ()

@property (nonatomic, strong) User *user;

@property (nonatomic, strong) NSMutableArray *groupList;

@end

@implementation GOGroupsViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.groupList = [[NSMutableArray alloc] initWithCapacity:1];
    
    NSLog(@"game objectID: %@", self.game.title);
    
//    GOParseAPIClient *client = [GOParseAPIClient sharedClient];
//    client.delegate = self;
//    [client getGroupsForGameName:self.game.title];
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


#pragma mark - UITableView Delegates

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
    return self.groupList.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *MyIdentifier = @"MyIdentifier";
    
    GOGroupCell *cell = (GOGroupCell *)[tableView dequeueReusableCellWithIdentifier:MyIdentifier];
    if (cell == nil)
    {
        NSArray *nib = [[NSBundle mainBundle] loadNibNamed:@"GOGroupCell" owner:self options:nil];
        cell = [nib objectAtIndex:0];
    }
    
    Group *group = [self.groupList objectAtIndex:indexPath.row];
    
    cell.title.text = group.title;
    cell.creator.text = group.creator;
    cell.description.text = group.description;
    cell.currentPlayers.text = [NSString stringWithFormat:@"%d", group.membersOfParty.count];
    cell.maxPlayers.text = [NSString stringWithFormat:@"%@", group.maxPartySize];
    
    if (group.isPrivate) {
        cell.privateIV.hidden = NO;
    }
    
    if ([group.skillLevel isEqualToString:@"Beginner"]) {
        cell.skill.textColor = [UIColor greenColor];
    } else if ([group.skillLevel isEqualToString:@"Intermediate"]) {
        cell.skill.textColor = [UIColor blueColor];
    } else {
        cell.skill.textColor = [UIColor redColor];
    }
    cell.skill.text = group.skillLevel;
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    
    if (![PFUser currentUser]) {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Oops!" message:@"You must register/login before doing that." delegate:nil cancelButtonTitle:@"OK" otherButtonTitles: nil];
        [alert show];
        
        [self.tabBarController setSelectedIndex:2];
    }
    else
    {
        Group *group = [self.groupList objectAtIndex:indexPath.row];
        GOGroupDetailsViewController *gdvc = [[GOGroupDetailsViewController alloc] initWithNibName:@"GOGroupDetailsViewController" bundle:nil];
        gdvc.group = group;
        
        [self.navigationController pushViewController:gdvc animated:YES];
        
        [tableView deselectRowAtIndexPath:indexPath animated:YES];
    }
}

#pragma mark - ParseAPI Delegates

//- (void)GOParseAPIClient:(GOParseAPIClient *)client didGetGroupsForGame:(id)response {
//    NSLog(@"%@", response);
//    
//    for (NSDictionary *dict in [response objectForKey:@"results"]) {
//        Group *grp = [[Group alloc] init];
//        [grp groupWithDictionary:dict];
//        [self.groupList addObject:grp];
//    }
//    
//    [self.groupsTable reloadData];
//}
//
//-(void)GOParseAPIClient:(GOParseAPIClient *)client didFailWithError:(NSError *)error; {
//    UIAlertView *av = [[UIAlertView alloc] initWithTitle:@"Error" message:error.localizedDescription delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
//    [av show];
//}

@end
