//
//  GOSettingsViewController.m
//  Game On!
//
//  Created by Jordan Clifton on 7/22/13.
//  Copyright (c) 2013 Jordan Clifton. All rights reserved.
//

#import "GOSettingsViewController.h"
#import "GOLoginViewController.h"
#import "GORegisterViewController.h"

@interface GOSettingsViewController ()

@end

@implementation GOSettingsViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        self.title = @"Account";
        self.tabBarItem.image = [UIImage imageNamed:@"second"];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.view.backgroundColor = [UIColor colorWithPatternImage:[UIImage imageNamed:@"background.png"]];
    
    PFUser *currentUser = [PFUser currentUser];
    if (currentUser) {
        self.loginBtn.hidden = YES;
        self.regBtn.hidden = YES;
        self.logoutBtn.hidden = NO;
    } else {
        self.loginBtn.hidden = NO;
        self.regBtn.hidden = NO;
        self.logoutBtn.hidden = YES;
    }
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Button Actions

- (IBAction)loginPressed:(id)sender {
    
    if (![PFUser currentUser]) {
        // No user logged in
        GOLoginViewController *loginVC = [[GOLoginViewController alloc] init];
        loginVC.fields = PFLogInFieldsUsernameAndPassword
        | PFLogInFieldsLogInButton
        | PFLogInFieldsSignUpButton
        | PFLogInFieldsDismissButton;
        [loginVC setDelegate:self];
                
        [self presentViewController:loginVC animated:YES completion:nil];
    } else {
        NSLog(@"User already logged in");
    }
    
}

- (IBAction)registerPressed:(id)sender {
    
    GORegisterViewController *signupVC = [[GORegisterViewController alloc] init];
    signupVC.fields = PFSignUpFieldsSignUpButton
    | PFSignUpFieldsEmail
    | PFSignUpFieldsUsernameAndPassword
    | PFSignUpFieldsDismissButton;
    [signupVC setDelegate:self];
    
    [self presentViewController:signupVC animated:YES completion:nil];
    
}

- (IBAction)onLogout:(id)sender {
    [PFUser logOut];
    
    self.loginBtn.hidden = NO;
    self.regBtn.hidden = NO;
    self.logoutBtn.hidden = YES;
}

#pragma mark - login delegates

- (BOOL)logInViewController:(PFLogInViewController *)logInController shouldBeginLogInWithUsername:(NSString *)username password:(NSString *)password
{
    if (username && password && username.length != 0 && password.length != 0)
    {
        return YES;
    }
    
    [[[UIAlertView alloc] initWithTitle:@"Login Error"
                                message:@"Missing information"
                               delegate:nil
                      cancelButtonTitle:@"OK"
                      otherButtonTitles:nil]show];
    
    return NO;
}

- (void)logInViewController:(PFLogInViewController *)logInController didLogInUser:(PFUser *)user
{
    
    NSDictionary *userDict = [NSDictionary dictionaryWithObjectsAndKeys:user.username, @"username", user.email, @"email", user.sessionToken, @"sessionToken", user.objectId, @"objectId",  nil];
    User *user2 = [[User alloc] init];
    user2 = [user2 userWithDictionary:userDict];
    // Set NSUserDefault here
    
    self.loginBtn.hidden = YES;
    self.regBtn.hidden = YES;
    self.logoutBtn.hidden = NO;
    
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)logInViewController:(PFLogInViewController *)logInController didFailToLogInWithError:(NSError *)error
{
    NSLog(@"Error: %@", error.localizedDescription);
}

#pragma mark - Sign up delegates

- (BOOL)signUpViewController:(PFSignUpViewController *)signUpController shouldBeginSignUp:(NSDictionary *)info
{
    BOOL informationComplete = YES;
    
    for (id key in info) {
        NSString *field = [info objectForKey:key];
        if (!field || field.length == 0) {
            informationComplete = NO;
            break;
        }
    }
    
    if (!informationComplete) {
        [[[UIAlertView alloc] initWithTitle:@"Signup Error"
                                    message:@"Missing information"
                                   delegate:nil
                          cancelButtonTitle:@"OK"
                          otherButtonTitles:nil]show];
    }
    
    return informationComplete;
}

- (void)signUpViewController:(PFSignUpViewController *)signUpController didSignUpUser:(PFUser *)user
{
    NSDictionary *userDict = [NSDictionary dictionaryWithObjectsAndKeys:user.username, @"username", user.email, @"email", user.sessionToken, @"sessionToken", user.objectId, @"objectId",  nil];
    User *user2 = [[User alloc] init];
    user2 = [user2 userWithDictionary:userDict];
    // Set NSUserDefault here
    
    self.loginBtn.hidden = YES;
    self.regBtn.hidden = YES;
    self.logoutBtn.hidden = NO;
    
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)signUpViewController:(PFSignUpViewController *)signUpController didFailToSignUpWithError:(NSError *)error
{
    [[[UIAlertView alloc] initWithTitle:@"Signup Error"
                                message:@"Failed to sign up, try again"
                               delegate:nil
                      cancelButtonTitle:@"OK"
                      otherButtonTitles:nil]show];
}

- (void)signUpViewControllerDidCancelSignUp:(PFSignUpViewController *)signUpController
{
    
}

@end
